@@ -274,11 +274,18 @@ enum {
 	FUNCTION_ID_REM = 1734,
 	FUNCTION_ID_MOD = 1735,
 	FUNCTION_ID_PARALLEL = 1736,
+	FUNCTION_ID_POWER_MOD = 1737,
 	FUNCTION_ID_BERNOULLI = 1740,
 	FUNCTION_ID_TOTIENT = 1745,
 	FUNCTION_ID_RE = 1750,
 	FUNCTION_ID_IM = 1751,
 	FUNCTION_ID_ARG = 1752,
+	FUNCTION_ID_PRIME_COUNT = 1760,
+	FUNCTION_ID_NTH_PRIME = 1761,
+	FUNCTION_ID_PREV_PRIME = 1762,
+	FUNCTION_ID_NEXT_PRIME = 1763,
+	FUNCTION_ID_PRIMES = 1764,
+	FUNCTION_ID_IS_PRIME = 1765,
 	FUNCTION_ID_DIFFERENTIATE = 1800,
 	FUNCTION_ID_LIMIT = 1810,
 	FUNCTION_ID_INTEGRATE = 1820,
@@ -354,6 +361,10 @@ enum {
 	FUNCTION_ID_NEXT_LUNAR_PHASE = 2351,
 	FUNCTION_ID_INTERVAL = 2400,
 	FUNCTION_ID_UNCERTAINTY = 2401,
+	FUNCTION_ID_LOWER_END_POINT = 2402,
+	FUNCTION_ID_UPPER_END_POINT = 2403,
+	FUNCTION_ID_MID_POINT = 2404,
+	FUNCTION_ID_GET_UNCERTAINTY = 2404,
 	FUNCTION_ID_ASCII = 2500,
 	FUNCTION_ID_CHAR = 2501,
 	FUNCTION_ID_LENGTH = 2502,
@@ -500,6 +511,12 @@ DECLARE_BUILTIN_FUNCTION_R(AbsFunction, FUNCTION_ID_ABS)
 DECLARE_BUILTIN_FUNCTION_MT(GcdFunction, FUNCTION_ID_GCD)
 DECLARE_BUILTIN_FUNCTION_MT(LcmFunction, FUNCTION_ID_LCM)
 DECLARE_BUILTIN_FUNCTION(DivisorsFunction, FUNCTION_ID_DIVISORS)
+DECLARE_BUILTIN_FUNCTION_MT(PrimeCountFunction, FUNCTION_ID_PRIME_COUNT)
+DECLARE_BUILTIN_FUNCTION_MT(IsPrimeFunction, FUNCTION_ID_IS_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(NthPrimeFunction, FUNCTION_ID_NTH_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(PrimesFunction, FUNCTION_ID_PRIMES)
+DECLARE_BUILTIN_FUNCTION_MT(PrevPrimeFunction, FUNCTION_ID_PREV_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(NextPrimeFunction, FUNCTION_ID_NEXT_PRIME)
 DECLARE_BUILTIN_FUNCTION_R(SignumFunction, FUNCTION_ID_SIGNUM)
 DECLARE_BUILTIN_FUNCTION_R(RoundFunction, FUNCTION_ID_ROUND)
 DECLARE_BUILTIN_FUNCTION_R(FloorFunction, FUNCTION_ID_FLOOR)
@@ -511,9 +528,14 @@ DECLARE_BUILTIN_FUNCTION_MT(IntFunction, FUNCTION_ID_INT)
 DECLARE_BUILTIN_FUNCTION_MT(FracFunction, FUNCTION_ID_FRAC)
 DECLARE_BUILTIN_FUNCTION_MT(RemFunction, FUNCTION_ID_REM)
 DECLARE_BUILTIN_FUNCTION_MT(ModFunction, FUNCTION_ID_MOD)
+DECLARE_BUILTIN_FUNCTION_MT(PowerModFunction, FUNCTION_ID_POWER_MOD)
 DECLARE_BUILTIN_FUNCTION_MT(BernoulliFunction, FUNCTION_ID_BERNOULLI)
 DECLARE_BUILTIN_FUNCTION_MT(TotientFunction, FUNCTION_ID_TOTIENT)
 DECLARE_BUILTIN_FUNCTION(ParallelFunction, FUNCTION_ID_PARALLEL)
+DECLARE_BUILTIN_FUNCTION_MT(LowerEndPointFunction, FUNCTION_ID_LOWER_END_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(UpperEndPointFunction, FUNCTION_ID_UPPER_END_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(MidPointFunction, FUNCTION_ID_MID_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(GetUncertaintyFunction, FUNCTION_ID_GET_UNCERTAINTY)
 
 DECLARE_BUILTIN_FUNCTION(BinFunction, FUNCTION_ID_BIN)
 DECLARE_BUILTIN_FUNCTION(OctFunction, FUNCTION_ID_OCT)
